# Recommender_System_Proteomics
Scripts to run Recommender Systems on Proteomics data.

## Downloading:
  - click on the green "Code" button on the top right and Download ZIP, then unzip it  
  or use  
  - git clone https://github.com/ManuelGander/Recommender_System_Proteomics.git
  
## Running the scripts:
  - The notebook "Full_script.ipynb" contains all the information needed to run the scripts
